@@ -1,3 +1,4 @@
+from qsparse.convert import convert
 from qsparse.quantize import linear_quantize_callback, quantize
 from qsparse.sparse import prune, structured_prune_callback, unstructured_prune_callback
 from qsparse.util import auto_name_prune_quantize_layers
@@ -7,6 +8,7 @@ from qsparse.util import set_options as set_qsparse_options
 __all__ = (
     "quantize",
     "prune",
+    "convert",
     "linear_quantize_callback",
     "unstructured_prune_callback",
     "structured_prune_callback",
@@ -15,4 +17,4 @@ __all__ = (
     "get_qsparse_option",
 )
 
-__version__ = "1.0.1"
+__version__ = "1.1.0"
